Welcome to grafyaml's documentation!
====================================

.. include:: ../../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing
   grafana-dashboard
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

